#!/usr/bin/env python
"""
Assumes you have a database with a schema like:

CREATE TABLE user_passwd (
  username        varchar(60) not null,
  passwd        varchar(30) not null,
}

to hold the username and passwords
"""
from WMCore.Database.DBFactory import DBFactory
from UserStore import UserStore
from crypt import crypt
import logging, cherrypy

class DBUserStore(UserStore):
    def __init__(self, config):
        UserStore.__init__(self, config)
        logging.basicConfig(level = logging.DEBUG,
                format = '%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
                datefmt = '%m-%d %H:%M')
        self.logger = logging.getLogger('OIDDBUserStore')
        self.conn = DBFactory(self.logger, config.source).connect()
        
    def load(self, user):
        sql = """select * from group_responsibility, site_responsibility 
        where site_responsibility.CONTACT=group_responsibility.CONTACT 
        and group_responsibility.CONTACT=21"""
        return {'role'  : user, 
                'group' : user,
                'site'  : user,
                'fullname'  : user
                }
    
    def checkpass(self, user, password):
        sql = 'select passwd from user_passwd where username = :username'
        try:
            data = self.conn.processData(sql, binds = {'username': user})
            
            if len(data) == 1:
                encpassword = data[0].fetchone()[0]
                if encpassword == crypt(password, encpassword):
                    return True
        except Exception, e:
            self.logger.info(str(e))
        return False
    
    def checkdn(self, user, dn):
        sql = "select 'true' from dual where exists (select dn from contact where username='metson')"
        return False

    def getuserbydn(self, dn):
        return None
